from umsc.umsc import UgMultiScriptConverter
import pytest


test_data = [("qol", "qol"),
    ("baş", "bosh"),
    ("put", "put"),
    ("köz", "ko‘z"),
    ("ceñçi", "jangchi"),
    ("cudé", "jude"),
    ("san", "son"),
    ("sey", "say"),
    ("é", "e"),
    ("şir", "shir"),
    ("şañxey", "shongxay"),
    ("kitab", "kitob"),
    ("veten", "vatan"),
    ("tomur", "tomur"),
    ("kömür", "ko‘mu‘r"),
    ("éliktir", "eliktir"),
    ("vyétnam", "vyetnom"),
    ("şincañ", "shinjong"),
    ("anar", "onor"),
    ("encür", "anju‘r"),
    ("orda", "ordo"),
    ("uruş", "urush"),
    ("ördek", "o‘rdak"),
    ("üzüm", "u‘zu‘m"),
    ("élan", "elon"),
    ("inkas", "inkos"),
    ("inik'ana", "inik'ono"),
    ("es'et", "as'at"),
    ("radio", "rodio"),
    ("mes'ul", "mas'ul"),
    ("qariörük", "qorio‘ru‘k"),
    ("naümid", "nou‘mid"),
    ("it'éyiq", "it'eyiq"),
    ("cem'iy", "jam'iy"),
    ("nemen'gan", "naman'gon"),
    ("özxan", "o‘zxon"),
    ("pasxa", "posxo"),
    ("bayrimi", "boyrimi"),
    ("maarip", "moorip"),
    ("muellim", "muallim"),
    ("daire", "doira"),
    ("mueyyen", "muayyan"),
    ("tebiiy", "tabiiy"),
    ("paaliyet", "pooliyat"),
    ("ishaq", "ishoq"),
    ("özbékistanğa", "o‘zbekistong‘o"),
    ("hingan", "hingon"),
    ("çeklengen", "chaklangan"),
    ("gañgirap", "gonggirop"),
    ("başlanğuç", "boshlong‘uch"),
    ("cem'iyet", "jam'iyat"),
]

@pytest.mark.parametrize("input,expected", test_data)
def test_UAS2CTS(input, expected):
    converter = UgMultiScriptConverter("CTS", "UZBEK")
    assert converter(input) == expected
