from umsc.umsc import UgMultiScriptConverter
import pytest

test_data = [('qol', 'qal'),
             ('bosh', 'baş'),
             ('put', 'put'),
             ('ko‘z', 'köz'),
             ('jangchi', 'ceñçi'),
             ('jude', 'cudé'),
             ('son', 'san'),
             ('say', 'sey'),
             ('e', 'é'),
             ('shir', 'şir'),
             ('shongxay', 'şañxey'),
             ('kitob', 'kitab'),
             ('vatan', 'veten'),
             ('tomur', 'tamur'),
             ('ko‘mu‘r', 'kömür'),
             ('eliktir', 'éliktir'),
             ('vyetnom', 'vyétnam'),
             ('shinjong', 'şincañ'),
             ('onor', 'anar'),
             ('anju‘r', 'encür'),
             ('ordo', 'arda'),
             ('urush', 'uruş'),
             ('o‘rdak', 'ördek'),
             ('u‘zu‘m', 'üzüm'),
             ('elon', 'élan'),
             ('inkos', 'inkas'),
             ("inik'ono", "inik'ana"),
             ("as'at", "es'et"),
             ('rodio', 'radia'),
             ("mas'ul", "mes'ul"),
             ('qorio‘ru‘k', 'qariörük'),
             ('nou‘mid', 'naümid'),
             ("it'eyiq", "it'éyiq"),
             ("jam'iy", "cem'iy"),
             ("naman'gon", "nemengan"),
             ('o‘zxon', 'özxan'),
             ('posxo', 'pasxa'),
             ('boyrimi', 'bayrimi'),
             ('moorip', 'maarip'),
             ('muallim', 'muellim'),
             ('doira', 'daire'),
             ('muayyan', 'mueyyen'),
             ('tabiiy', 'tebiiy'),
             ('pooliyat', 'paaliyet'),
             ("is'hoq", 'ishaq'),
             ("o‘zbekiston'g‘o", "özbékistanğa"),
             ("hin'gon", "hingan"),
             ("chaklan'gan", 'çeklengen'),
             ('gonggirop', 'gañgirap'),
             ("boshlon'g‘uch", 'başlanğuç'),
             ("jam'iyat", "cem'iyet")
             ]

@pytest.mark.parametrize("input,expected", test_data)
def test_UAS2CTS(input, expected):
    converter = UgMultiScriptConverter("UZBEK", "CTS")
    assert converter(input) == expected
