from umsc.umsc import UgMultiScriptConverter
import pytest


test_data = [
    ("قول", "қол"),
    ("باش", "баш"),
    ("پۇت", "пут"),
    ("كۆز", "көз"),
    ("جەڭچى", "җәңчи"),
    ("جۇدې", "җуде"),
    ("سان", "сан"),
    ("سەي", "сәй"),
    ("ئې", "е"),
    ("شىر", "шир"),
    ("شاڭخەي", "шаңхәй"),
    ("كىتاب", "китаб"),
    ("ۋەتەن", "вәтән"),
    ("تومۇر", "томур"),
    ("كۆمۈر", "көмүр"),
    ("ئېلىكتىر", "еликтир"),
    ("ۋيېتنام", "вйетнам"),
    ("شىنجاڭ", "шинҗаң"),
    ("ئانار", "анар"),
    ("ئەنجۈر", "әнҗүр"),
    ("ئوردا", "орда"),
    ("ئۇرۇش", "уруш"),
    ("ئۆردەك", "өрдәк"),
    ("ئۈزۈم", "үзүм"),
    ("ئېلان", "елан"),
    ("ئىنكاس", "инкас"),
    ("ئىنىكئانا", "иник'ана"),
    ("ئەسئەت", "әс'әт"),
    ("رادىئو", "ради'о"),
    ("مەسئۇل", "мәс'ул"),
    ("قارىئۆرۈك", "қари'өрүк"),
    ("نائۈمىد", "на'үмид"),
    ("ئىتئېيىق", "ит'ейиқ"),
    ("جەمئىي", "җәм'ий"),
    ("نەمەنگان", "нәмәнган"),
    ("ئۆزخان", "өзхан"),
    ("پاسخا", "пасха"),
    ("بايرىمى", "байрими"),
    ("مائارىپ", "ма'арип"),
    ("مۇئەللىم", "му'әллим"),
    ("دائىرە", "да'ирә"),
    ("مۇئەييەن", "му'әййән"),
    ("تەبىئىي", "тәби'ий"),
    ("پائالىيەت", "па'алийәт"),
    ("ئىسھاق", "исһақ"),
    ("ئۆزبېكىستانغا", "өзбекистанға"),
    ("ھىنگان", "һинган"),
    ("چەكلەنگەن", "чәкләнгән"),
    ("گاڭگىراپ", "гаңгирап"),
    ("باشلانغۇچ", "башланғуч"),
    ("جەمئىيەت", "җәм'ийәт"),
    # ("جۇڭخۇا", "җуңхуа|ⱪol"),
]

test_data = [(value, key) for key, value in test_data]

@pytest.mark.parametrize("input,expected", test_data)
def test_UAS2CTS(input, expected):
    converter = UgMultiScriptConverter("UCS", "UAS")
    assert converter(input) == expected
